@@ -33,9 +33,10 @@
 #  define KDEWEBKIT_DEPRECATED_NO_EXPORT KDEWEBKIT_NO_EXPORT KDEWEBKIT_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KDEWEBKIT_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KDEWEBKIT_NO_DEPRECATED
+#    define KDEWEBKIT_NO_DEPRECATED
+#  endif
 #endif
 
-#endif
+#endif /* KDEWEBKIT_EXPORT_H */
